TimeTable class

타임테이블 위젯 Timetable widget

Inheritance

Constructors

TimeTable({Key? key, required List<String> columnHeaders, required Map<String, List<TimetableEvent>> events, int? startTime, int? endTime, double headerHeight = 30.0, double timeHeaderWidth = 30.0, double cellHeight = 60.0, Color gridColor = const Color(0xFFE0E0E0), Color? headerBackgroundColor, Color? timeHeaderBackgroundColor, Color? cellBackgroundColor, BoxDecoration? headerDecoration, BoxDecoration? timeHeaderDecoration, BoxDecoration? cellDecoration, BoxDecoration? eventCellDecoration, TextStyle? headerTextStyle, TextStyle? timeTextStyle, TextStyle? eventTextStyle, BorderRadius? borderRadius, dynamic onEventTap(TimetableEvent)?})
const

Properties

borderRadius BorderRadius?
final
cellBackgroundColor Color?
final
cellDecoration BoxDecoration?
final
cellHeight double
final
columnHeaders List<String>
final
endTime int?
final
eventCellDecoration BoxDecoration?
final
events Map<String, List<TimetableEvent>>
final
eventTextStyle TextStyle?
final
gridColor Color
final
hashCode int
The hash code for this object.
no setterinherited
headerBackgroundColor Color?
final
headerDecoration BoxDecoration?
final
headerHeight double
final
headerTextStyle TextStyle?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onEventTap → dynamic Function(TimetableEvent)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTime int?
final
timeHeaderBackgroundColor Color?
final
timeHeaderDecoration BoxDecoration?
final
timeHeaderWidth double
final
timeTextStyle TextStyle?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited