TimetableEvent class

타임테이블 이벤트를 나타내는 클래스 Class representing a timetable event

Constructors

TimetableEvent({required String title, required DateTime startTime, required DateTime endTime, Color? color, String? description})
const

Properties

color Color?
final
description String?
final
durationMinutes int
이벤트 지속 시간 (분 단위) Event duration in minutes
no setter
endMinutes int
종료 시간을 분 단위로 변환 (0시 0분을 기준으로) Convert end time to minutes (based on 00:00)
no setter
endTime DateTime
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startMinutes int
시작 시간을 분 단위로 변환 (0시 0분을 기준으로) Convert start time to minutes (based on 00:00)
no setter
startTime DateTime
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited